import {useQuery} from 'react-query'
import {isNotEmpty, QUERIES} from '../../../../../../../_metronic/helpers'
import { useListView } from '../person/ListViewProviderPerson'
import {getPersonById, getPositionById} from '../../core/_requests'
import { PersonAddModalForm } from './PersonAddModalForm'

const PersonAddModalFormWrapper = () => {
  const {itemIdForUpdate, setItemIdForUpdate} = useListView()
  const enabledQuery: boolean = isNotEmpty(itemIdForUpdate)
  const {
    isLoading,
    data: position,
    error,
  } = useQuery(
    `${QUERIES.POSITIONS_LIST}-position-${itemIdForUpdate}`,
    () => {
      return getPositionById(itemIdForUpdate)
    },
    {
      cacheTime: 0,
      enabled: enabledQuery,
      onError: (err) => {
        setItemIdForUpdate(undefined)
        console.error(err)
      },
    }
  )
  if (!itemIdForUpdate) {
    return <PersonAddModalForm isPositionLoading={isLoading} position={{id: undefined}} />
  }
  if (!isLoading && !error && position) {
    return <PersonAddModalForm isPositionLoading={isLoading} position={position} />
  }

  return null
}

export {PersonAddModalFormWrapper}
